@@ -43,24 +43,23 @@ class _Property(Protocol[SELF, OUT]):
 
 
 class cached_property(property, _Property[SELF, OUT]):
-    '''decorator for converting a method into a cached property'''
-
-    # https://stackoverflow.com/a/4037979/3671939
-    # setattr(instance, name, value) raises
-    #   AttributeError: Can't set attribute.
-    # Using my own caching system with "self._cache"
-
-    _cache: OUT
+    '''
+    decorator for converting a method into a cached property
+    See https://stackoverflow.com/a/4037979/3671939
+    This uses a modification:
+    1. inherit from property, which disables setattr(instance, name, value)
+        as it raises AttributeError: Can't set attribute
+    2. use instance.__dict__[name] = value to fix
+    '''
 
     def __init__(self, method: Callable[[SELF], OUT]):
-        self._method: Optional[Callable[[SELF], OUT]] = method
+        self._method = method
 
     def __get__(self, instance: SELF, _) -> OUT:
-        if self._method is None:
-            return self._cache
-        self._cache = self._method(instance)
-        self._method = None
-        return self._cache
+        name = self._method.__name__
+        value = self._method(instance)
+        instance.__dict__[name] = value
+        return value
 
 
 def set_method(cls):
